{% load i18n %}
<div id="form{{ content.id }}">
  {% if content.show_form_title %}
    <h2>{{ content.form.title }}</h2>
  {% endif %}
  {% if form %}
  <form method="post" action="#form{{ content.id }}">{% csrf_token %}
    <input type="hidden" name="_formcontent" value="{{ content.id }}">
    <table>
      {{ form }}
      <tr>
        <td>&nbsp;</td>
        <td><input type="submit" value="{% trans "Submit" %}"></td>
      </tr>
    </table>
  </form>
  {% else %}
    {{ message|safe }}
  {% endif %}
</div>
